@@ -130,11 +130,15 @@ G_GNUC_CONST static gint badchar(char c)
 static char *unlinkify_text(const char *text)
 {
   const char *c, *t, *q = NULL;
-  const char *URL = "U R L";
+  const char *URL;
   const int BUF_LEN = 1024;
   char *tmp;
   char url_buf[BUF_LEN * 4];
+
+  URL=_("U R L");
+
   GString *ret = g_string_new("");
+
   /* Assumes you have a buffer able to cary at least BUF_LEN * 2 bytes */
   
   c = text;
@@ -167,7 +171,7 @@ static char *unlinkify_text(const char *text)
 	  
 	  if (*(t - 1) == '.')
 	    t--;
-	  g_string_append_printf(ret, URL);
+	  g_string_append(ret, URL);
 	  c = t;
 	  break;
 	}
@@ -192,7 +196,7 @@ static char *unlinkify_text(const char *text)
 	    
 	    if (*(t - 1) == '.')
 	      t--;
-	    g_string_append_printf(ret, URL);
+	    g_string_append(ret, URL);
 	    c = t;
 	    break;
 	  }
@@ -207,7 +211,7 @@ static char *unlinkify_text(const char *text)
 	if (badchar(*t)) {
 	  if (*(t - 1) == '.')
 	    t--;
-	  g_string_append_printf(ret, URL);
+	  g_string_append(ret, URL);
 	  c = t;
 	  break;
 	}
@@ -226,7 +230,7 @@ static char *unlinkify_text(const char *text)
 	    }
 	    if (*(t - 1) == '.')
 	      t--;
-	    g_string_append_printf(ret, URL);
+	    g_string_append(ret, URL);
 	    c = t;
 	    break;
 	  }
@@ -241,7 +245,7 @@ static char *unlinkify_text(const char *text)
 	if (badchar(*t)) {
 	  if (*(t - 1) == '.')
 	    t--;
-	  g_string_append_printf(ret, URL);
+	  g_string_append(ret, URL);
 	  c = t;
 	  break;
 	}
@@ -280,7 +284,7 @@ static char *unlinkify_text(const char *text)
       
       while (flag) {
 	if (badchar(*t)) {
-	  g_string_append_printf(ret, URL);
+	  g_string_append(ret, URL);
 	  c = t;
 	  
 	  break;
@@ -315,9 +319,9 @@ static void speak(GString *text)
       if( strchr("¿¡\"!@#$%^&*()[]{}<>/|~`\r\n\0,.+-_:;'",text->str[i]))
 	text->str[i] = ' ';
 
-    g_string_printf(buffer,"(SayText \"%s\")\n", text->str);
+    g_string_printf(buffer,"(SayText \"%s\")", text->str);
     purple_debug(PURPLE_DEBUG_INFO, "pidgin festival", buffer->str);
-    fprintf(festival_pf,buffer->str);
+    fputs(buffer->str,festival_pf);
     fflush(festival_pf);
     g_string_free(buffer,TRUE);
   }
@@ -331,18 +335,18 @@ static const char *get_best_name(PurpleAccount *account, char const * who)
 }
 
 static void
-im_recv_im(PurpleAccount *account, char *who, char *what, int flags, void *m)
+im_recv_im(PurpleAccount *account, char *who, char *what,
+	    PurpleConversation * conv, PurpleMessageFlags flags)
 {
   char *stripped;
   const char *alias = get_best_name(account, who);
   silent_joins = NULL;
 
   GString *buffer= g_string_new("");
-  GString *ascii;
-  ascii = g_string_new(g_convert (what, strlen (what),
-				  "ISO-8859-1", "UTF-8",
-				  NULL, NULL, NULL));
-  stripped = (char *)purple_markup_strip_html(ascii->str);
+
+/*  msg_utf8=purple_utf8_try_convert(what) */
+
+  stripped = (char *)purple_markup_strip_html(/*msg_utf8?msg_utf8:*/what);
     
   if(purple_prefs_get_bool("/plugins/gtk/festival/speaker/replace_url"))
     stripped = unlinkify_text(stripped);
@@ -363,8 +367,8 @@ im_recv_im(PurpleAccount *account, char *who, char *what, int flags, void *m)
   }
 
   g_free(stripped);
+/*  if (msg_utf8) g_free(msg_utf8); */
   g_string_free(buffer,TRUE);
-  g_string_free(ascii, TRUE);
 }
 
 static void
@@ -385,13 +389,13 @@ _event_speak(const char *buddy, char *state)
 static void
 buddy_signed_on_cb(struct _PurpleBuddy *buddy, void *data)
 {
-  _event_speak((char *) purple_buddy_get_alias(buddy),"signed on");
+  _event_speak((char *) purple_buddy_get_alias(buddy),_("signed on"));
 }
 
 static void
 buddy_signed_off_cb(struct _PurpleBuddy *buddy, void *data)
 {
-  _event_speak((char *) purple_buddy_get_alias(buddy), "signed off");
+  _event_speak((char *) purple_buddy_get_alias(buddy), _("signed off"));
 }
 
 static void
